﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Infragistics.Web.UI.NavigationControls;

namespace IG14TestControls
{
    public class WebExplorerBarItemState
    {
        public bool NodeState { get; set; }
        public bool Selected { get; set; }
        public List<WebExplorerBarItemState> ItemStates = new List<WebExplorerBarItemState>();
    }

    /// <summary>
    /// Class to save the state (expanded/selected) of all nodes in the WebExplorerBar 
    /// control so we can restore it across pages.
    /// </summary>
    public class WebExplorerBarState
    {
        public List<WebExplorerBarItemState> _groupStates = new List<WebExplorerBarItemState>();

        public WebExplorerBarState(WebExplorerBar webExplorer)
        {
            foreach (ExplorerBarGroup group in webExplorer.Groups)
            {
                WebExplorerBarItemState groupState = new WebExplorerBarItemState();
                groupState.NodeState = group.Expanded;
                groupState.Selected = group.Selected;
                _groupStates.Add(groupState);

                if (group.HasChildren)
                    GetItemStates(group.Items, groupState);
            }
        }

        private void GetItemStates(ExplorerBarItemCollection items, WebExplorerBarItemState itemState)
        {
            foreach (ExplorerBarItem subItem in items)
            {
                WebExplorerBarItemState subItemState = new WebExplorerBarItemState();
                subItemState.NodeState = subItem.Expanded;
                subItemState.Selected = subItem.Selected;
                itemState.ItemStates.Add(subItemState);

                if (subItem.HasChildren)
                    GetItemStates(subItem.Items, subItemState);
            }
        }

        public static void SetWebExplorerBarState(WebExplorerBar webExplorer, WebExplorerBarState webState)
        {
            foreach (ExplorerBarGroup group in webExplorer.Groups)
            {
                group.Expanded = webState._groupStates[group.Index].NodeState;
                group.Selected = webState._groupStates[group.Index].Selected;

                bool isSelected = false;
                if (group.HasChildren)
                    SetItemStates(group.Items, webState._groupStates[group.Index], ref isSelected);

                if (isSelected)
                    group.Selected = true;

                /*
                if (group.Selected)
                {
                    group.ImageUrl = group.ImageUrl.Replace("_gray", "_white");

                    group.ActiveCssClass = "webs_GroupActive";
                    group.CssClass = "webs_Group";
                    group.DisabledCssClass = "webs_GroupDisabled";
                    group.HoverCssClass = "webs_GroupHover";
                    group.SelectedCssClass = "webs_GroupSelected";
                }
                else
                {
                    group.ImageUrl = group.ImageUrl.Replace("_white", "_gray");
                }
                */
            }
        }

        private static void SetItemStates(ExplorerBarItemCollection items, WebExplorerBarItemState itemState, ref bool isSelected)
        {
            foreach (ExplorerBarItem subItem in items)
            {
                subItem.Expanded = itemState.ItemStates[subItem.Index].NodeState;
                subItem.Selected = itemState.ItemStates[subItem.Index].Selected;

                if (subItem.Selected)
                    isSelected = true;

                /*
                if (subItem.Selected && !subItem.HasChildren)
                {
                    subItem.ActiveCssClass = "webs_ItemActive";
                    subItem.CssClass = "webs_Item";
                    subItem.DisabledCssClass = "webs_ItemDisabled";
                    subItem.HoverCssClass = "webs_ItemHover";
                    subItem.SelectedCssClass = "webs_ItemSelected";

                    subItem.NavigateUrl = subItem.Value;
                }
                */

                if (subItem.HasChildren)
                    SetItemStates(subItem.Items, itemState.ItemStates[subItem.Index], ref isSelected);
            }
        }

        public static void SetWebExplorerBarStyle(WebExplorerBar webExplorer)
        {
            foreach (ExplorerBarGroup group in webExplorer.Groups)
            {
                bool isSelected = false;
                if (group.HasChildren)
                    SetItemStyles(group.Items, ref isSelected);

                if (group.Selected || isSelected)
                {
                    group.ActiveCssClass = "webs_GroupActive";
                    group.CssClass = "webs_Group";
                    group.DisabledCssClass = "webs_GroupDisabled";
                    group.HoverCssClass = "webs_GroupHover";
                    group.SelectedCssClass = "webs_GroupSelected";
                }
            }
        }

        private static void SetItemStyles(ExplorerBarItemCollection items, ref bool isSelected)
        {
            foreach (ExplorerBarItem subItem in items)
            {
                if (subItem.Selected)
                    isSelected = true;

                if (subItem.Selected && !subItem.HasChildren)
                {
                    subItem.ActiveCssClass = "webs_ItemActive";
                    subItem.CssClass = "webs_Item";
                    subItem.DisabledCssClass = "webs_ItemDisabled";
                    subItem.HoverCssClass = "webs_ItemHover";
                    subItem.SelectedCssClass = "webs_ItemSelected";

                    subItem.NavigateUrl = subItem.Value;
                }

                if (subItem.HasChildren)
                    SetItemStyles(subItem.Items, ref isSelected);
            }
        }
    }
}